@@ -502,11 +502,13 @@ def stitching_setup(ctx, argument, concurrency, output):
         frames_folder = call_folder / "annotated_frames"
         frames_folder.mkdir(parents=True, exist_ok=True)
 
-        for frame_url in input_data.get('annotated_frames', []):
-            frame_path = frames_folder / get_filename_from_url(frame_url)
-            files_to_load.append([
-                frame_url, frame_path
-            ])
+        annotated_frames = input_data.get('annotated_frames', [])
+        if annotated_frames:
+            for frame_url in annotated_frames:
+                frame_path = frames_folder / get_filename_from_url(frame_url)
+                files_to_load.append([
+                    frame_url, frame_path
+                ])
 
         ctx.verbose_log(f'Creating a stitching input for run #{call_count} into {call_folder}')
         with open(str(call_folder / "stitching_input.json"), 'w') as fp:
