@@ -33,3 +33,14 @@ class RCDB:
         (HEAT_MAP, 'Heat map information'),
         (SIZES, 'Sizes information'),
     )
+
+
+class DownloadImagesFormat(object):
+    FULL = "full"
+    IMAGES = "images"
+    ANNOTATIONS = "annotations"
+    OPTIONS = [
+        FULL,
+        IMAGES,
+        ANNOTATIONS,
+    ]
