@@ -159,3 +159,10 @@ class AdminProvider(ReboticsBaseProvider):
     @remote_service('/core-test/cases/{id}/')
     def get_core_test_case(self, id_):
         return self.session.get(id=id_)
+
+    @remote_service('/core-test/cases/')
+    def list_core_test_cases(self, **params):
+        """
+        Expected params are: `group`, `title`
+        """
+        return self.session.get(params=params)
