@@ -156,7 +156,9 @@ class ProviderRequestProxy(object):
             raise ProviderHTTPClientException(http_error_msg, response=response)
         elif response.status_code in [502, 503]:
             raise RetryableException(
-                'Deployment might be in progress, or server is overloaded')
+                'Deployment might be in progress, or server is overloaded',
+                response=response
+            )
         elif 500 <= response.status_code < 600:
             raise ProviderHTTPClientException('%d Server error. %s ' % (
                 response.status_code,
@@ -167,8 +169,10 @@ class ProviderRequestProxy(object):
         request_arguments = self.augment_request_arguments(**request_arguments)
         retries = 0
         retry_errors = []
+        response = None
 
-        while retries < self.retries:
+        # if we say, that there should be no retries, put retries=0
+        while retries < self.retries + 1:
             try:
                 self.set_file_caret_to_start(**request_arguments)
                 response = getattr(requests, method)(**request_arguments)
@@ -181,12 +185,14 @@ class ProviderRequestProxy(object):
                 time.sleep(self.retry_delay)
             except requests.ConnectionError as exc:
                 retry_errors.append(exc)
-                raise ProviderHTTPServiceException('Service is not working with error: %s' % exc)
+                raise ProviderHTTPServiceException('Service is not working with error: %s' % exc,
+                                                   response=response)
             else:
                 break  # Exits while loop
         else:
-            raise ProviderHTTPServiceException('Failed to do request after {} tries'.format(MAX_RETRIES),
-                                               retries=retry_errors)
+            raise ProviderHTTPServiceException('Failed to do request after {} tries'.format(len(retry_errors)),
+                                               retries=retry_errors,
+                                               response=response)
 
         return self.format_return_data(response)
 
@@ -237,7 +243,7 @@ class UniqueRequestProxy(ProviderRequestProxy):
                 error_desc = json_resp['error']
             except (ValueError, TypeError, KeyError):
                 error_desc = 'Another request is already processing'
-            raise RetryableException(error_desc)
+            raise RetryableException(error_desc, response=response)
 
         return super(UniqueRequestProxy, self).raise_if_error_status_code(response)
 
